
.. _ini:

INI Files
*********

Also known as initialisation files.  These are in some cases used to store
translations.

.. _ini#conformance:

Conformance
===========

The toolkit uses `iniparse <https://pypi.org/project/iniparse/>`_, an INI file
parser that preserves layout and follows the .ini format as supported by the
Python language.

.. _ini#dialects:

Dialects
--------

The format supports two dialects:

- default: standard iniparse handling of INI files
- inno: follows `Inno <http://www.innosetup.com/files/istrans/>`_ escaping
  conventions

.. _ini#references:

References
==========

Further information is available on .ini files:

- Wikipedia :wp:`INI file format <INI_file>` article
- `Unofficial specification <http://www.cloanto.com/specs/ini/>`_
